@@ -31,6 +31,8 @@ import (
 	"github.com/osrg/gobgp/table"
 )
 
+var _regexpCommunity = regexp.MustCompile(`\^\^(\S+)\$\$`)
+
 func formatDefinedSet(head bool, typ string, indent int, list []table.DefinedSet) string {
 	if len(list) == 0 {
 		return "Nothing defined yet\n"
@@ -59,13 +61,12 @@ func formatDefinedSet(head bool, typ string, indent int, list []table.DefinedSet
 		}
 		for i, x := range l {
 			if typ == "COMMUNITY" || typ == "EXT-COMMUNITY" || typ == "LARGE-COMMUNITY" {
-				exp := regexp.MustCompile("\\^\\^(\\S+)\\$\\$")
-				x = exp.ReplaceAllString(x, "$1")
+				x = _regexpCommunity.ReplaceAllString(x, "$1")
 			}
 			if i == 0 {
 				buff.WriteString(fmt.Sprintf(format, s.Name(), x))
 			} else {
-				buff.WriteString(fmt.Sprintf(sIndent))
+				buff.WriteString(fmt.Sprint(sIndent))
 				buff.WriteString(fmt.Sprintf(format, "", x))
 			}
 		}
@@ -333,12 +334,16 @@ func printStatement(indent int, s *table.Statement) {
 			fmt.Printf("%sExtCommunitySet: %s %s\n", ind, t.Option(), t.Name())
 		case *table.LargeCommunityCondition:
 			fmt.Printf("%sLargeCommunitySet: %s %s\n", ind, t.Option(), t.Name())
+		case *table.NextHopCondition:
+			fmt.Printf("%sNextHopInList: %s\n", ind, t.String())
 		case *table.AsPathLengthCondition:
 			fmt.Printf("%sAsPathLength: %s\n", ind, t.String())
 		case *table.RpkiValidationCondition:
 			fmt.Printf("%sRPKI result: %s\n", ind, t.String())
 		case *table.RouteTypeCondition:
 			fmt.Printf("%sRoute Type: %s\n", ind, t.String())
+		case *table.AfiSafiInCondition:
+			fmt.Printf("%sAFI SAFI In: %s\n", ind, t.String())
 		}
 	}
 
@@ -480,7 +485,7 @@ func modCondition(name, op string, args []string) error {
 	}
 	usage := fmt.Sprintf("usage: gobgp policy statement %s %s condition", name, op)
 	if len(args) < 1 {
-		return fmt.Errorf("%s { prefix | neighbor | as-path | community | ext-community | large-community | as-path-length | rpki | route-type }", usage)
+		return fmt.Errorf("%s { prefix | neighbor | as-path | community | ext-community | large-community | as-path-length | rpki | route-type | next-hop-in-list | afi-safi-in }", usage)
 	}
 	typ := args[0]
 	args = args[1:]
@@ -637,8 +642,20 @@ func modCondition(name, op string, args []string) error {
 		default:
 			return err
 		}
+	case "next-hop-in-list":
+		stmt.Conditions.BgpConditions.NextHopInList = args
+	case "afi-safi-in":
+		afiSafisInList := make([]config.AfiSafiType, 0, len(args))
+		for _, arg := range args {
+			afiSafi := config.AfiSafiType(arg)
+			if err := afiSafi.Validate(); err != nil {
+				return err
+			}
+			afiSafisInList = append(afiSafisInList, afiSafi)
+		}
+		stmt.Conditions.BgpConditions.AfiSafiInList = afiSafisInList
 	default:
-		return fmt.Errorf("%s { prefix | neighbor | as-path | community | ext-community | large-community | as-path-length | rpki | route-type }", usage)
+		return fmt.Errorf("%s { prefix | neighbor | as-path | community | ext-community | large-community | as-path-length | rpki | route-type | next-hop-in-list | afi-safi-in }", usage)
 	}
 
 	t, err := table.NewStatement(stmt)
@@ -762,6 +779,9 @@ func modAction(name, op string, args []string) error {
 		stmt.Actions.BgpActions.SetNextHop = config.BgpNextHopType(args[0])
 	}
 	t, err := table.NewStatement(stmt)
+	if err != nil {
+		return err
+	}
 	switch op {
 	case CMD_ADD:
 		err = client.AddStatement(t)
