@@ -22,9 +22,11 @@ import (
 	"strconv"
 	"strings"
 
-	"github.com/spf13/cobra"
-
+	api "github.com/osrg/gobgp/api"
 	"github.com/osrg/gobgp/packet/bgp"
+
+	"github.com/golang/protobuf/ptypes/any"
+	"github.com/spf13/cobra"
 )
 
 func getVrfs() (vrfs, error) {
@@ -56,21 +58,35 @@ func showVrfs() error {
 	lines := make([][]string, 0, len(vrfs))
 	for _, v := range vrfs {
 		name := v.Name
-		rd := v.Rd.String()
+		rd, err := api.UnmarshalRD(v.Rd)
+		if err != nil {
+			return err
+		}
+		rdStr := rd.String()
 
-		f := func(rts []bgp.ExtendedCommunityInterface) (string, error) {
+		f := func(rts []*any.Any) (string, error) {
 			ret := make([]string, 0, len(rts))
-			for _, rt := range rts {
+			for _, an := range rts {
+				rt, err := api.UnmarshalRT(an)
+				if err != nil {
+					return "", err
+				}
 				ret = append(ret, rt.String())
 			}
 			return strings.Join(ret, ", "), nil
 		}
 
-		importRts, _ := f(v.ImportRt)
-		exportRts, _ := f(v.ExportRt)
-		lines = append(lines, []string{name, rd, importRts, exportRts, fmt.Sprintf("%d", v.Id)})
+		importRts, err := f(v.ImportRt)
+		if err != nil {
+			return err
+		}
+		exportRts, err := f(v.ExportRt)
+		if err != nil {
+			return err
+		}
+		lines = append(lines, []string{name, rdStr, importRts, exportRts, fmt.Sprintf("%d", v.Id)})
 
-		for i, v := range []int{len(name), len(rd), len(importRts), len(exportRts)} {
+		for i, v := range []int{len(name), len(rdStr), len(importRts), len(exportRts)} {
 			if v > maxLens[i] {
 				maxLens[i] = v + 4
 			}
@@ -137,7 +153,9 @@ func modVrf(typ string, args []string) error {
 				return err
 			}
 		}
-		err = client.AddVRF(name, int(id), rd, importRt, exportRt)
+		if err := client.AddVRF(name, int(id), rd, importRt, exportRt); err != nil {
+			return err
+		}
 	case CMD_DEL:
 		if len(args) != 1 {
 			return fmt.Errorf("Usage: gobgp vrf del <vrf name>")
@@ -148,7 +166,6 @@ func modVrf(typ string, args []string) error {
 }
 
 func NewVrfCmd() *cobra.Command {
-
 	ribCmd := &cobra.Command{
 		Use: CMD_RIB,
 		Run: func(cmd *cobra.Command, args []string) {
