@@ -24,6 +24,7 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func keepalive() *BGPMessage {
@@ -38,25 +39,32 @@ func refresh() *BGPMessage {
 	return NewBGPRouteRefreshMessage(1, 2, 10)
 }
 
+var result []string
+
+func BenchmarkNormalizeFlowSpecOpValues(b *testing.B) {
+	var r []string
+	for n := 0; n < b.N; n++ {
+		r = normalizeFlowSpecOpValues([]string{"&<=80"})
+	}
+	result = r
+}
+
 func Test_Message(t *testing.T) {
 	l := []*BGPMessage{keepalive(), notification(), refresh(), NewTestBGPOpenMessage(), NewTestBGPUpdateMessage()}
+
 	for _, m1 := range l {
-		buf1, _ := m1.Serialize()
+		buf1, err := m1.Serialize()
+		assert.NoError(t, err)
+
 		t.Log("LEN =", len(buf1))
 		m2, err := ParseBGPMessage(buf1)
-		if err != nil {
-			t.Error(err)
-		}
-		// FIXME: shouldn't but workaround for some structs.
-		buf2, _ := m2.Serialize()
+		assert.NoError(t, err)
 
-		if reflect.DeepEqual(m1, m2) == true {
-			t.Log("OK")
-		} else {
-			t.Error("Something wrong")
-			t.Error(len(buf1), m1, buf1)
-			t.Error(len(buf2), m2, buf2)
-		}
+		// FIXME: shouldn't but workaround for some structs.
+		_, err = m2.Serialize()
+		assert.NoError(t, err)
+
+		assert.True(t, reflect.DeepEqual(m1, m2))
 	}
 }
 
@@ -81,7 +89,7 @@ func Test_RouteTargetMembershipNLRIString(t *testing.T) {
 
 	// TwoOctetAsSpecificExtended
 	buf := make([]byte, 13)
-	buf[0] = 12
+	buf[0] = 96 // in bit length
 	binary.BigEndian.PutUint32(buf[1:5], 65546)
 	buf[5] = byte(EC_TYPE_TRANSITIVE_TWO_OCTET_AS_SPECIFIC) // typehigh
 	binary.BigEndian.PutUint16(buf[7:9], 65000)
@@ -98,6 +106,7 @@ func Test_RouteTargetMembershipNLRIString(t *testing.T) {
 
 	// IPv4AddressSpecificExtended
 	buf = make([]byte, 13)
+	buf[0] = 96 // in bit length
 	binary.BigEndian.PutUint32(buf[1:5], 65546)
 	buf[5] = byte(EC_TYPE_TRANSITIVE_IP4_SPECIFIC) // typehigh
 	ip := net.ParseIP("10.0.0.1").To4()
@@ -115,6 +124,7 @@ func Test_RouteTargetMembershipNLRIString(t *testing.T) {
 
 	// FourOctetAsSpecificExtended
 	buf = make([]byte, 13)
+	buf[0] = 96 // in bit length
 	binary.BigEndian.PutUint32(buf[1:5], 65546)
 	buf[5] = byte(EC_TYPE_TRANSITIVE_FOUR_OCTET_AS_SPECIFIC) // typehigh
 	buf[6] = byte(EC_SUBTYPE_ROUTE_TARGET)                   // subtype
@@ -132,6 +142,7 @@ func Test_RouteTargetMembershipNLRIString(t *testing.T) {
 
 	// OpaqueExtended
 	buf = make([]byte, 13)
+	buf[0] = 96 // in bit length
 	binary.BigEndian.PutUint32(buf[1:5], 65546)
 	buf[5] = byte(EC_TYPE_TRANSITIVE_OPAQUE) // typehigh
 	binary.BigEndian.PutUint32(buf[9:], 1000000)
@@ -147,6 +158,7 @@ func Test_RouteTargetMembershipNLRIString(t *testing.T) {
 
 	// Unknown
 	buf = make([]byte, 13)
+	buf[0] = 96 // in bit length
 	binary.BigEndian.PutUint32(buf[1:5], 65546)
 	buf[5] = 0x04 // typehigh
 	binary.BigEndian.PutUint32(buf[9:], 1000000)
@@ -381,26 +393,24 @@ func Test_FlowSpecNlri(t *testing.T) {
 	lastFragment := uint64(0x08)
 	item5 := NewFlowSpecComponentItem(BITMASK_FLAG_OP_MATCH, isFragment)
 	item6 := NewFlowSpecComponentItem(BITMASK_FLAG_OP_AND, lastFragment)
+
 	cmp = append(cmp, NewFlowSpecComponent(FLOW_SPEC_TYPE_FRAGMENT, []*FlowSpecComponentItem{item5, item6}))
 	item7 := NewFlowSpecComponentItem(0, TCP_FLAG_ACK)
 	item8 := NewFlowSpecComponentItem(BITMASK_FLAG_OP_AND|BITMASK_FLAG_OP_NOT, TCP_FLAG_URGENT)
+
 	cmp = append(cmp, NewFlowSpecComponent(FLOW_SPEC_TYPE_TCP_FLAG, []*FlowSpecComponentItem{item7, item8}))
 	n1 := NewFlowSpecIPv4Unicast(cmp)
+
 	buf1, err := n1.Serialize()
 	assert.Nil(err)
+
 	n2, err := NewPrefixFromRouteFamily(RouteFamilyToAfiSafi(RF_FS_IPv4_UC))
 	assert.Nil(err)
+
 	err = n2.DecodeFromBytes(buf1)
 	assert.Nil(err)
-	buf2, _ := n2.Serialize()
-	if reflect.DeepEqual(n1, n2) == true {
-		t.Log("OK")
-	} else {
-		t.Error("Something wrong")
-		t.Error(len(buf1), n1, buf1)
-		t.Error(len(buf2), n2, buf2)
-		t.Log(bytes.Equal(buf1, buf2))
-	}
+	// should be equal
+	assert.Equal(n1, n2)
 }
 
 func Test_FlowSpecExtended(t *testing.T) {
@@ -414,42 +424,36 @@ func Test_FlowSpecExtended(t *testing.T) {
 	exts = append(exts, NewTrafficRemarkExtended(10))
 	m1 := NewPathAttributeExtendedCommunities(exts)
 	buf1, err := m1.Serialize()
-	assert.Nil(err)
+	require.NoError(t, err)
+
 	m2 := NewPathAttributeExtendedCommunities(nil)
 	err = m2.DecodeFromBytes(buf1)
-	assert.Nil(err)
-	buf2, _ := m2.Serialize()
-	if reflect.DeepEqual(m1, m2) == true {
-		t.Log("OK")
-	} else {
-		t.Error("Something wrong")
-		t.Error(len(buf1), m1, buf1)
-		t.Error(len(buf2), m2, buf2)
-	}
+	require.NoError(t, err)
+
+	_, err = m2.Serialize()
+	require.NoError(t, err)
+
+	assert.Equal(m1, m2)
 }
 
 func Test_IP6FlowSpecExtended(t *testing.T) {
-	assert := assert.New(t)
 	exts := make([]ExtendedCommunityInterface, 0)
 	exts = append(exts, NewRedirectIPv6AddressSpecificExtended("2001:db8::68", 1000))
 	m1 := NewPathAttributeIP6ExtendedCommunities(exts)
 	buf1, err := m1.Serialize()
-	assert.Nil(err)
+	require.NoError(t, err)
+
 	m2 := NewPathAttributeIP6ExtendedCommunities(nil)
 	err = m2.DecodeFromBytes(buf1)
-	assert.Nil(err)
-	buf2, _ := m2.Serialize()
-	if reflect.DeepEqual(m1, m2) == true {
-		t.Log("OK")
-	} else {
-		t.Error("Something wrong")
-		t.Error(len(buf1), m1, buf1)
-		t.Error(len(buf2), m2, buf2)
-	}
+	require.NoError(t, err)
+
+	_, err = m2.Serialize()
+	require.NoError(t, err)
+
+	assert.Equal(t, m1, m2)
 }
 
 func Test_FlowSpecNlriv6(t *testing.T) {
-	assert := assert.New(t)
 	cmp := make([]FlowSpecComponentInterface, 0)
 	cmp = append(cmp, NewFlowSpecDestinationPrefix6(NewIPv6AddrPrefix(64, "2001::"), 12))
 	cmp = append(cmp, NewFlowSpecSourcePrefix6(NewIPv6AddrPrefix(64, "2001::"), 12))
@@ -474,20 +478,18 @@ func Test_FlowSpecNlriv6(t *testing.T) {
 	cmp = append(cmp, NewFlowSpecComponent(FLOW_SPEC_TYPE_TCP_FLAG, []*FlowSpecComponentItem{item6, item7}))
 	n1 := NewFlowSpecIPv6Unicast(cmp)
 	buf1, err := n1.Serialize()
-	assert.Nil(err)
+	require.NoError(t, err)
+
 	n2, err := NewPrefixFromRouteFamily(RouteFamilyToAfiSafi(RF_FS_IPv6_UC))
-	assert.Nil(err)
+	require.NoError(t, err)
+
 	err = n2.DecodeFromBytes(buf1)
-	assert.Nil(err)
-	buf2, _ := n2.Serialize()
-	if reflect.DeepEqual(n1, n2) == true {
-		t.Log("OK")
-	} else {
-		t.Error("Something wrong")
-		t.Error(len(buf1), n1, buf1)
-		t.Error(len(buf2), n2, buf2)
-		t.Log(bytes.Equal(buf1, buf2))
-	}
+	require.NoError(t, err)
+
+	_, err = n2.Serialize()
+	require.NoError(t, err)
+
+	assert.Equal(t, n1, n2)
 }
 
 func Test_Aigp(t *testing.T) {
@@ -495,19 +497,13 @@ func Test_Aigp(t *testing.T) {
 	m := NewAigpTLVIgpMetric(1000)
 	a1 := NewPathAttributeAigp([]AigpTLVInterface{m})
 	buf1, err := a1.Serialize()
-	assert.Nil(err)
+	require.NoError(t, err)
+
 	a2 := NewPathAttributeAigp(nil)
 	err = a2.DecodeFromBytes(buf1)
-	assert.Nil(err)
-	buf2, _ := a2.Serialize()
-	if reflect.DeepEqual(a1, a2) == true {
-		t.Log("OK")
-	} else {
-		t.Error("Something wrong")
-		t.Error(len(buf1), a1, buf1)
-		t.Error(len(buf2), a2, buf2)
-		t.Log(bytes.Equal(buf1, buf2))
-	}
+	require.NoError(t, err)
+
+	assert.Equal(a1, a2)
 }
 
 func Test_FlowSpecNlriL2(t *testing.T) {
@@ -526,15 +522,8 @@ func Test_FlowSpecNlriL2(t *testing.T) {
 	assert.Nil(err)
 	err = n2.DecodeFromBytes(buf1)
 	assert.Nil(err)
-	buf2, _ := n2.Serialize()
-	if reflect.DeepEqual(n1, n2) == true {
-		t.Log("OK")
-	} else {
-		t.Error("Something wrong")
-		t.Error(len(buf1), n1, buf1)
-		t.Error(len(buf2), n2, buf2)
-		t.Log(bytes.Equal(buf1, buf2))
-	}
+
+	assert.Equal(n1, n2)
 }
 
 func Test_NotificationErrorCode(t *testing.T) {
@@ -558,16 +547,9 @@ func Test_FlowSpecNlriVPN(t *testing.T) {
 	n2, err := NewPrefixFromRouteFamily(RouteFamilyToAfiSafi(RF_FS_IPv4_VPN))
 	assert.Nil(err)
 	err = n2.DecodeFromBytes(buf1)
-	assert.Nil(err)
-	buf2, _ := n2.Serialize()
-	if reflect.DeepEqual(n1, n2) == true {
-		t.Log("OK")
-	} else {
-		t.Error("Something wrong")
-		t.Error(len(buf1), n1, buf1)
-		t.Error(len(buf2), n2, buf2)
-		t.Log(bytes.Equal(buf1, buf2))
-	}
+	require.NoError(t, err)
+
+	assert.Equal(n1, n2)
 }
 
 func Test_EVPNIPPrefixRoute(t *testing.T) {
@@ -592,17 +574,8 @@ func Test_EVPNIPPrefixRoute(t *testing.T) {
 	assert.Nil(err)
 	err = n2.DecodeFromBytes(buf1)
 	assert.Nil(err)
-	buf2, _ := n2.Serialize()
-	t.Log(n1.RouteTypeData.(*EVPNIPPrefixRoute).ESI.Value, n2.(*EVPNNLRI).RouteTypeData.(*EVPNIPPrefixRoute).ESI.Value)
-	t.Log(reflect.DeepEqual(n1.RouteTypeData.(*EVPNIPPrefixRoute).ESI.Value, n2.(*EVPNNLRI).RouteTypeData.(*EVPNIPPrefixRoute).ESI.Value))
-	if reflect.DeepEqual(n1, n2) {
-		t.Log("OK")
-	} else {
-		t.Error("Something wrong")
-		t.Error(len(buf1), n1, buf1)
-		t.Error(len(buf2), n2, buf2)
-		t.Log(bytes.Equal(buf1, buf2))
-	}
+
+	assert.Equal(n1, n2)
 }
 
 func Test_CapExtendedNexthop(t *testing.T) {
@@ -613,15 +586,8 @@ func Test_CapExtendedNexthop(t *testing.T) {
 	assert.Nil(err)
 	n2, err := DecodeCapability(buf1)
 	assert.Nil(err)
-	buf2, _ := n2.Serialize()
-	if reflect.DeepEqual(n1, n2) {
-		t.Log("OK")
-	} else {
-		t.Error("Something wrong")
-		t.Error(len(buf1), n1, buf1)
-		t.Error(len(buf2), n2, buf2)
-		t.Log(bytes.Equal(buf1, buf2))
-	}
+
+	assert.Equal(n1, n2)
 }
 
 func Test_AddPath(t *testing.T) {
@@ -801,15 +767,8 @@ func Test_MpReachNLRIWithIPv4MappedIPv6Prefix(t *testing.T) {
 	assert.Nil(err)
 	err = n2.DecodeFromBytes(buf1)
 	assert.Nil(err)
-	buf2, _ := n2.Serialize()
-	if reflect.DeepEqual(n1, n2) {
-		t.Log("OK")
-	} else {
-		t.Error("Something wrong")
-		t.Error(len(buf1), n1, buf1)
-		t.Error(len(buf2), n2, buf2)
-		t.Log(bytes.Equal(buf1, buf2))
-	}
+
+	assert.Equal(n1, n2)
 
 	label := NewMPLSLabelStack(2)
 
@@ -820,16 +779,8 @@ func Test_MpReachNLRIWithIPv4MappedIPv6Prefix(t *testing.T) {
 	assert.Nil(err)
 	err = n4.DecodeFromBytes(buf1)
 	assert.Nil(err)
-	buf2, _ = n3.Serialize()
-	t.Log(n3, n4)
-	if reflect.DeepEqual(n3, n4) {
-		t.Log("OK")
-	} else {
-		t.Error("Something wrong")
-		t.Error(len(buf1), n3, buf1)
-		t.Error(len(buf2), n4, buf2)
-		t.Log(bytes.Equal(buf1, buf2))
-	}
+
+	assert.Equal(n3, n4)
 }
 
 func Test_MpReachNLRIWithIPv6PrefixWithIPv4Peering(t *testing.T) {
@@ -1119,7 +1070,7 @@ func Test_ParseEthernetSegmentIdentifier(t *testing.T) {
 
 	// "single-homed"
 	esiZero := EthernetSegmentIdentifier{}
-	args := make([]string, 0, 0)
+	args := make([]string, 0)
 	esi, err := ParseEthernetSegmentIdentifier(args)
 	assert.Nil(err)
 	assert.Equal(esiZero, esi)
@@ -1215,3 +1166,29 @@ func TestFuzzCrashers(t *testing.T) {
 		ParseBGPMessage([]byte(f))
 	}
 }
+
+func TestNormalizeFlowSpecOpValues(t *testing.T) {
+	tests := []struct {
+		msg  string
+		args []string
+		want []string
+	}{
+		{
+			msg:  "valid match",
+			args: []string{"  &  <=80", " tcp  != udp ", " =!   SA   & =U!  F", " =  is-fragment+last-fragment"},
+			want: []string{"<=80", "tcp", "!=udp", "=!SA", "&=U", "!F", "=is-fragment+last-fragment"},
+		},
+		{
+			msg:  "RFC5575 trims & prefix",
+			args: []string{"&<=80"},
+			want: []string{"<=80"},
+		},
+	}
+
+	for _, tt := range tests {
+		t.Run(tt.msg, func(t *testing.T) {
+			got := normalizeFlowSpecOpValues(tt.args)
+			assert.Equal(t, tt.want, got)
+		})
+	}
+}
