@@ -48,6 +48,9 @@ BGP_ATTR_TYPE_CLUSTER_LIST = 10
 BGP_ATTR_TYPE_MP_REACH_NLRI = 14
 BGP_ATTR_TYPE_EXTENDED_COMMUNITIES = 16
 
+GRACEFUL_RESTART_TIME = 30
+LONG_LIVED_GRACEFUL_RESTART_TIME = 30
+
 FLOWSPEC_NAME_TO_TYPE = {
     "destination": 1,
     "source": 2,
