@@ -15,6 +15,7 @@
 
 from __future__ import absolute_import
 
+import collections
 import json
 from itertools import chain
 from threading import Thread
@@ -27,9 +28,9 @@ from fabric.utils import indent
 import netaddr
 import toml
 import yaml
-import collections
 
 from lib.base import (
+    community_str,
     wait_for_completion,
     BGPContainer,
     CmdBuffer,
@@ -39,7 +40,8 @@ from lib.base import (
     BGP_ATTR_TYPE_LOCAL_PREF,
     BGP_ATTR_TYPE_COMMUNITIES,
     BGP_ATTR_TYPE_MP_REACH_NLRI,
-    community_str,
+    GRACEFUL_RESTART_TIME,
+    LONG_LIVED_GRACEFUL_RESTART_TIME,
 )
 
 
@@ -113,7 +115,13 @@ class GoBGPContainer(BGPContainer):
         local(cmd, capture=True)
         self.local("{0}/start.sh".format(self.SHARED_VOLUME), detach=True)
 
-    def graceful_restart(self):
+    def start_gobgp(self, graceful_restart=False):
+        if self._is_running():
+            raise RuntimeError('GoBGP is already running')
+        self._start_gobgp(graceful_restart=graceful_restart)
+        self._wait_for_boot()
+
+    def stop_gobgp(self):
         self.local("pkill -INT gobgpd")
 
     def _start_zebra(self):
@@ -439,7 +447,7 @@ class GoBGPContainer(BGPContainer):
                     v['prefix-limit'] = {'config': {'max-prefixes': info['prefix_limit'], 'shutdown-threshold-pct': 80}}
 
             if info['graceful_restart'] is not None:
-                n['graceful-restart'] = {'config': {'enabled': True, 'restart-time': 20}}
+                n['graceful-restart'] = {'config': {'enabled': True, 'restart-time': GRACEFUL_RESTART_TIME}}
                 for afi_safi in afi_safi_list:
                     afi_safi['mp-graceful-restart'] = {'config': {'enabled': True}}
 
@@ -447,7 +455,7 @@ class GoBGPContainer(BGPContainer):
                     n['graceful-restart']['config']['restart-time'] = 1
                     n['graceful-restart']['config']['long-lived-enabled'] = True
                     for afi_safi in afi_safi_list:
-                        afi_safi['long-lived-graceful-restart'] = {'config': {'enabled': True, 'restart-time': 30}}
+                        afi_safi['long-lived-graceful-restart'] = {'config': {'enabled': True, 'restart-time': LONG_LIVED_GRACEFUL_RESTART_TIME}}
 
             if info['is_rr_client']:
                 cluster_id = self.router_id
